@@ -77,8 +77,5 @@ class SqlServer(object):
             table_name,
             upsets
         )
-        print(sql)
-        print(*values)
-        print(values)
         self.execute(sql, *values)
 
